import sys
import pandas as pd
import matplotlib
matplotlib.use("TkAgg")
import matplotlib.pyplot as plt


def plot_csv(csv_file, x_axis, y_axis, plot_type):
    # Read CSV file into a DataFrame
    try:
        df = pd.read_csv(csv_file)
    except FileNotFoundError:
        print(f"Error: File not found at {csv_file}")
        return
    except pd.errors.EmptyDataError:
        print(f"Error: The CSV file at {csv_file} is empty.")
        return

    # Check if the entered headers exist in the DataFrame
    if x_axis not in df.columns or y_axis not in df.columns:
        print("Error: One or both of the specified headers do not exist.")
        return

    # Plot the data based on the chosen plot type
    if plot_type == "scatter":
        plt.scatter(df[x_axis], df[y_axis], label=f"{y_axis} vs {x_axis}")
    elif plot_type == "line":
        plt.plot(df[x_axis], df[y_axis], label=f"{y_axis} vs {x_axis}")
    elif plot_type == "bar":
        plt.bar(df[x_axis], df[y_axis], label=f"{y_axis} vs {x_axis}")
    else:
        print("Error: Invalid plot type. Choose from 'scatter', 'line', or 'bar'.")
        return

    plt.title(f"{plot_type.capitalize()} Plot: {y_axis} vs {x_axis}")
    plt.xlabel(x_axis)
    plt.ylabel(y_axis)
    plt.legend()

    # Show the plot
    plt.show()

if __name__ == "__main__":
    # Check if the correct number of command-line arguments is provided
    if len(sys.argv) != 5:
        print("Usage: python plot_csv.py <csv_file_path> <x_axis_header> <y_axis_header> <plot_type>")
    else:
        csv_file_path, x_axis_header, y_axis_header, plot_type = sys.argv[1:5]

##        # Check for missing arguments
##        if not csv_file_path:
##            print("Error: CSV file path is missing.")
##        elif not x_axis_header:
##            print("Error: X-axis header is missing.")
##        elif not y_axis_header:
##            print("Error: Y-axis header is missing.")
##        elif not plot_type:
##            print("Error: Plot type is missing.")
##        else:
        plot_csv(csv_file_path, x_axis_header, y_axis_header, plot_type.lower())
